import vimeo_api
import preference_manager

class PrefEPy:
    def __init__(self, address = None):
        #For use with flask if needed later
        self.address = address
    def update_response(self):
        pass

    def get_videos(self):
        return preference_manager.test_videos()


import vimeo

class VimeoApi:
    def __init__(self):
        CLIENT_IDENTIFIER = unicode("ecc42707d88b1ff5659a831eaae849cca76c7c43", ("utf-8"))
        CLIENT_SECRET = unicode(
            "G5fT0yPeH69GyvQUsrKPklA+3Quqg16oplLy1k8edL5tssv97GPbbNoeqgr36l1MCUor4sws8pK71n+Ie/6wCPgeB+FvfbiDO6lktRxD3xOj3aMi5w6OPKIASog+I1X6",
            ("utf-8"))
        TOKEN = unicode("e770e2ac7592ee362e177aa337d41f80", ("utf-8"))
        VIMEO_OAUTH_HEADERS = {
            'Accept': 'application/vnd.vimeo.*+json;version=3.0',
            'Authorization': TOKEN
        }
        self.v = vimeo.VimeoClient(
            token=TOKEN,
            key=CLIENT_IDENTIFIER,
            secret=CLIENT_SECRET
        )

    def get_category_vids(self, category, num_videos):
        url = 'https://api.vimeo.com/categories/sports/videos?sort=date&direction=desc&privacy.embed=public&content_rating=safe&featured=true'

        sport_vids = self.v.get(url)
        sport_vids_dict = sport_vids.json()
        return sport_vids_dict


import sys
from flask import Flask
from flask import request
from flask import jsonify
from flask_cors import CORS
import json
import isodate
import vimeo_api

#Initializes the communication to the youtube api
#client = yt_api.get_yt_service()

#Allows the program to be run using Flask calls ***not sure the right way to articulate this***
app = Flask(__name__)

#Allows the methods to be called from a  different orgin IP address
CORS(app)

#Returns a youtube id of the video best suited to be show to a given user or user
@app.route("/videos", methods=["GET"])
def get_videos():
    db = database.get_database()

    region_id = request.args.get('region_id')
    max_results = request.args.get('max_results')
    category_id = str(request.args.get('category_id'))
    retrieval_count = int(request.args.get('retrieval_count'))
    user_ids = json.loads(request.args.get('user_ids'))

    #Returns a list of tuples [(id, duration), (id, duration)]
    # TODO parse date time format in yt_api
    vid_ids = yt_api.get_top_vids(client, region_id.replace("'", ""), max_results, category_id.replace("'", ""))

    #test id's
    if (retrieval_count % 2 == 0):
        vid_ids = [("9825762", isodate.parse_duration('PT4M27S').total_seconds()),("59829500", isodate.parse_duration('PT12S').total_seconds()) ,("43032498" , isodate.parse_duration('PT26S').total_seconds()),("5226362", isodate.parse_duration('PT49S').total_seconds())]
    else:
        vid_ids = [("59829500", isodate.parse_duration('PT12S').total_seconds()) ,("9825762", isodate.parse_duration('PT4M27S').total_seconds()),("5226362", isodate.parse_duration('PT49S').total_seconds()),("43032498" , isodate.parse_duration('PT26S').total_seconds())]

    #add each video that has been returned by the youtube call, to the data base if not in the data base
    for vid_id in vid_ids:
        if vid_id[0] not in db['videos']:
            db = database.add_video(db, vid_id[0], 'youtube', vid_id[0])

    #For each user in the room
    for user_id in user_ids:
        #Add user to the data base if not in the data base
        if user_id not in db['users']:
            db = database.add_user(db, user_id)
        #For each video that is returned to the kanvas
        for vid_id in vid_ids:
            db = database.add_video_view(db, vid_id[0])
            db = database.add_user_view(db, user_id, vid_id[0])

    database.save_database(db)
    return jsonify(vid_ids)

#Updates the like value of a given video for the given user

@app.route("/test", methods = ["GET"])
def test_videos():
    test = [ {"command" : {"type": command, "scene": "vimeo", "context" : {"type":"video", "id": "43032498", "loop": False}},"type":"command"}]

    return jsonify(test)

@app.route("/user/preferences/video", methods=["GET", "PUT"])
def update_response():
    db = database.get_database()

    user_id = request.args.get("uuid")
    preference = request.args.get("like")
    video_id = request.args.get("video_id")

    if user_id not in db['users']:
        db = database.add_user(db, user_id)

    if video_id not in db['videos']:
        db = database.add_video(db, video_id, 'youtube', video_id)

    db = database.update_user_response(db, user_id, video_id, preference)
    db = database.update_video_repsonses(db, video_id, user_id, preference)

    database.save_database(db)
    #return jsonify(database.get_stats(database, video_id))
    return('Like updated')


from setuptools import setup

setup(name = 'prefepy',
	version='0.0.2',
	description='Prefence manager module to gather and show content to users',
	url='http://github.com/ballcarsen/',
	author='Carsen Ball',
	author_email='carsen@NEXTstory.com',
	license='Next Story Group, Carsen Ball',
	packages=['prefepy'],
	install_requires=['Flask-Cors','isodate', 'PyVimeo'],
	zip_safe=False)
